@@ -22,26 +22,62 @@
 
 #include <exception>
 #include <iostream>
-#include "cxxtools/iniclass.h"
+#include <fstream>
+#include <iterator>
+#include <cxxtools/inifile.h>
+#include <cxxtools/loginit.h>
+#include <cxxtools/arg.h>
+
+log_define("cxxtools.getini")
 
 int main(int argc, char* argv[])
 {
+  log_init();
+
   try
   {
-    if (argc < 4)
+    cxxtools::Arg<bool> quiet(argc, argv, 'q');
+
+    if (argc <= 1)
     {
       std::cerr << "usage: " << argv[0]
-        << " inifile section key [default]" << std::endl;
+        << " inifile [-q] [section [key [default]]]" << std::endl;
       return -1;
     }
 
     const char* fname = argv[1];
+    std::ifstream in(fname);
+    if (!in)
+      throw std::runtime_error(std::string("error reading input file \"") + fname + '"');
+
+    cxxtools::IniFile ini(in);
+
+    if (argc <= 2)
+    {
+      // list sections
+      if (!quiet)
+        std::cout << "sections in " << fname << ": ";
+      ini.getSections(std::ostream_iterator<std::string>(std::cout, "\t"));
+      std::cout << std::endl;
+      return 0;
+    }
+
     const char* section = argv[2];
+    if (argc <= 3)
+    {
+      // list keys
+      if (!quiet)
+        std::cout << "keys in " << fname << " [" << section << "]: ";
+      ini.getKeys(section, std::ostream_iterator<std::string>(std::cout, "\t"));
+      std::cout << std::endl;
+      return 0;
+    }
+
     const char* key = argv[3];
     const char* defvalue = argv[4] ? argv[4] : "";
-
-    cxxtools::ini_file iniFile(fname);
-    std::cout << iniFile.get_value(section, key, defvalue) << std::endl;
+    if (!quiet)
+      std::cout << "value of " << fname << " [" << section << "]." << key << ": ";
+    std::cout << ini.getValue(section, key, defvalue) << std::endl;
   }
   catch (const std::exception& e)
   {
