@@ -23,6 +23,7 @@
 #define CXXTOOLS_THREAD_H
 
 #include <pthread.h>
+#include <signal.h>
 #include <semaphore.h>
 #include <stdexcept>
 #include <time.h>
@@ -39,8 +40,8 @@ namespace cxxtools
 class ThreadException : public SysError
 {
   public:
-    ThreadException(int errno, const char* method)
-      : SysError(errno, method)
+    ThreadException(int err, const char* method)
+      : SysError(err, method)
       { }
 };
 
@@ -63,6 +64,7 @@ class Thread
     virtual ~Thread();
 
     virtual void create() = 0;
+    void kill(int signo = SIGTERM);
 
   protected:
     virtual void run() = 0;
@@ -338,6 +340,30 @@ class LockBase
       { return mutex; }
 };
 
+template <typename mutex_type = Mutex,
+          bool (mutex_type::*unlock_method)() = &mutex_type::unlockNoThrow>
+class UnlockMonitor
+{
+    mutex_type* mutex;
+
+  public:
+    explicit UnlockMonitor(mutex_type& mutex_)
+      : mutex(&mutex_)
+      { }
+
+    ~UnlockMonitor()
+    {
+      if (mutex)
+        (mutex->*unlock_method)();
+    }
+
+    void unlock()
+    {
+      (mutex->*unlock_method)();
+      mutex = 0;
+    }
+};
+
 typedef LockBase<Mutex> MutexLock;
 typedef LockBase<RWLock, &RWLock::rdLock> RdLock;
 typedef LockBase<RWLock, &RWLock::wrLock> WrLock;
