@@ -21,9 +21,12 @@
 
 #include <cxxtools/httprequest.h>
 #include <cxxtools/base64stream.h>
+#include <cxxtools/log.h>
 #include <sstream>
 #include <cctype>
 
+log_define("cxxtools.httprequest")
+
 namespace cxxtools
 {
   HttpRequest::HttpRequest(const std::string& url_, request_type method_)
@@ -36,7 +39,8 @@ namespace cxxtools
       pos = 7;
 
     std::string::size_type e = url_.find(':', pos);
-    if (e != std::string::npos)
+    std::string::size_type e2 = url_.find('/', pos);
+    if (e != std::string::npos && (e2 == std::string::npos || e2 > e))
     {
       host = url_.substr(pos, e - pos);
       port = 0;
@@ -57,7 +61,16 @@ namespace cxxtools
       host = url_.substr(pos, e - pos);
     }
 
-    url = url_.substr(e);
+    std::string::size_type q = url_.find('?', e);
+    if (q != std::string::npos)
+    {
+      url = url_.substr(e, q - e);
+      params.parse_url(url_.substr(q + 1));
+    }
+    else
+      url = url_.substr(e);
+
+    log_debug("host=" << host << " port=" << port << " url=" << url << " qparams=" << params.getUrl());
   }
 
   void HttpRequest::setAuth(const std::string& username, const std::string& password)
@@ -70,12 +83,12 @@ namespace cxxtools
     addHeader("Authorization:", value.str());
   }
 
-  void HttpRequest::execute()
+  net::iostream& HttpRequest::execute()
   {
     if (reading)
     {
       if (connection.peek() != std::ios::traits_type::eof())
-        return;
+        return connection;
 
       connection.close();
       connection.clear();
@@ -121,6 +134,8 @@ namespace cxxtools
         break;
     }
     reading = true;
+
+    return connection;
   }
 
 }
