@@ -43,10 +43,6 @@
 #include <cctype>
 #include <pwd.h>
 #include <grp.h>
-#include <config.h>
-#ifdef HAVE_SCHED_YIELD
-#include <sched.h>
-#endif
 
 log_define("cxxtools.log")
 
@@ -94,29 +90,6 @@ namespace cxxtools
 
       static std::string mkfilename(unsigned idx);
 
-      class FlusherThread : public DetachedThread
-      {
-          std::ostream& out;
-          static struct timespec flushDelay;
-
-        protected:
-          void run();
-
-        public:
-          FlusherThread(std::ostream& out_)
-            : out(out_)
-            { }
-
-          static void setFlushDelay(unsigned ms)
-          {
-            flushDelay.tv_sec = ms / 1000;
-            flushDelay.tv_nsec = ms % 1000;
-          }
-      };
-
-      static FlusherThread* flusherThread;
-      static bool flusherThreadStarted;
-
     public:
       LoggerImpl(const std::string& c, log_level_type l)
         : Logger(c, l)
@@ -142,6 +115,7 @@ namespace cxxtools
       {
         outfile.clear();
         outfile.open(fname.c_str(), std::ios::out | std::ios::app);
+        counter.resetCount(outfile.tellp());
       }
 
       if (maxfilesize > 0)
@@ -164,13 +138,7 @@ namespace cxxtools
 
   void LoggerImpl::logEnd(std::ostream& appender)
   {
-    if (flusherThread == 0)
-      appender.flush();
-    else if (!flusherThreadStarted && !fname.empty())
-    {
-      flusherThread->create();
-      flusherThreadStarted = true;
-    }
+    appender.flush();
   }
 
   std::string LoggerImpl::mkfilename(unsigned idx)
@@ -211,12 +179,8 @@ namespace cxxtools
   net::UdpOStream LoggerImpl::udpmessage(LoggerImpl::loghost);
   unsigned LoggerImpl::maxfilesize = 0;
   unsigned LoggerImpl::maxbackupindex = 0;
-  LoggerImpl::FlusherThread* LoggerImpl::flusherThread = 0;
-  bool LoggerImpl::flusherThreadStarted = false;
   Pipestream* LoggerImpl::pipe = 0;
 
-  struct timespec LoggerImpl::FlusherThread::flushDelay;
-
   void LoggerImpl::setFile(const std::string& fname_)
   {
     fname = fname_;
@@ -226,15 +190,6 @@ namespace cxxtools
     counter.resetCount(ret == 0 ? s.st_size : 0);
   }
 
-  void LoggerImpl::setFlushDelay(unsigned ms)
-  {
-    FlusherThread::setFlushDelay(ms);
-    if (ms > 0 && flusherThread == 0 && !fname.empty())
-      flusherThread = new FlusherThread(outfile);
-    else if (ms == 0)
-      flusherThread = 0;
-  }
-
   void LoggerImpl::setLoghost(const std::string& host, unsigned short int port)
   {
     loghost.connect(host.c_str(), port, true);
@@ -281,9 +236,6 @@ namespace cxxtools
 
       setUserAndGroup(pw, gr);
 
-      counter.resetCount(outfile.tellp());
-
-
       log_debug("logger process initialized");
       char ich;
       std::ostream& out = getAppender();
@@ -292,7 +244,7 @@ namespace cxxtools
         char ch = std::ios::traits_type::to_char_type(ich);
         out.rdbuf()->sputc(ch);
         if (ch == '\n')
-          getAppender();
+          getAppender().flush();
       }
       exit(0);
     }
@@ -513,11 +465,6 @@ namespace cxxtools
       Logger* logger;
       const char* level;
 
-      static Mutex queueMutex;
-      typedef std::vector<std::string> MessageQueueType;
-      static MessageQueueType messageQueue;
-      void flushQueue();
-
     public:
       LogMessageImpl(Logger* logger_, const char* level_)
         : logger(logger_),
@@ -525,66 +472,17 @@ namespace cxxtools
           { }
 
       std::ostream& out()     { return msg; }
-      void flush();
-  };
-
-  Mutex LogMessage::LogMessageImpl::queueMutex;
-  LogMessage::LogMessageImpl::MessageQueueType LogMessage::LogMessageImpl::messageQueue;
-
-  void LogMessage::LogMessageImpl::flush()
-  {
-    if (Logger::mutex.tryLock())
-    {
-      UnlockMonitor<> unlocker(Logger::mutex);
-
-      std::ostream& out(logger->logentry(level));
-      out << msg.str() << '\n';
-
-      MutexLock lock(queueMutex);
-      flushQueue();
-      unlocker.unlock();
-    }
-    else
-    {
-      std::ostringstream logmessage;
-      Logger::logentry(logmessage, level, logger->getCategory());
-      logmessage << msg.str();
-
-#ifdef HAVE_SCHED_YIELD
-      sched_yield();
-#endif
-
-      MutexLock lock(queueMutex);
-      messageQueue.push_back(logmessage.str());
-
-      if (Logger::mutex.tryLock())
+      void flush()
       {
-        UnlockMonitor<> unlocker(Logger::mutex);
-        flushQueue();
-      }
-    }
-  }
+        MutexLock lock(Logger::mutex);
 
-  void LogMessage::LogMessageImpl::flushQueue()
-  {
-    std::ostream& out = LoggerImpl::getAppender();
-    if (!messageQueue.empty())
-    {
-      /*
-      static unsigned count = 0;
-      count += messageQueue.size();
-      if (messageQueue.size() == 1)
-        std::cerr << '.';
-      else
-        std::cerr << '[' << messageQueue.size() << '/' << count << ']';
-      */
-      for (MessageQueueType::const_iterator it = messageQueue.begin();
-           it != messageQueue.end(); ++it)
-        out << *it << '\n';
-      messageQueue.clear();
-    }
-    logger->logEnd(out);
-  }
+        std::ostream& out(logger->logentry(level));
+        out << msg.str() << '\n';
+
+        logger->logEnd(out);
+      }
+
+  };
 
   LogMessage::LogMessage(Logger* logger, const char* level)
     : impl(new LogMessageImpl(logger, level))
@@ -645,16 +543,6 @@ namespace cxxtools
     }
   }
 
-  void LoggerImpl::FlusherThread::run()
-  {
-    while (flushDelay.tv_sec > 0 || flushDelay.tv_nsec > 0)
-    {
-      nanosleep(&flushDelay, 0);
-      cxxtools::MutexLock lock(Logger::mutex);
-      out.flush();
-    }
-  }
-
 }
 
 void log_init_cxxtools(cxxtools::Logger::log_level_type level)
@@ -696,8 +584,6 @@ void log_init_cxxtools(std::istream& in)
     state_fsize,
     state_maxbackupindex0,
     state_maxbackupindex,
-    state_flushdelay0,
-    state_flushdelay,
     state_disable,
     state_logprocess,
     state_logprocessuser0,
@@ -717,7 +603,6 @@ void log_init_cxxtools(std::istream& in)
   unsigned short int port;
   unsigned fsize;
   unsigned maxbackupindex;
-  unsigned flushdelay = 0;
   bool logprocess = false;
   std::string logprocessuser;
   std::string logprocessgroup;
@@ -758,8 +643,6 @@ void log_init_cxxtools(std::istream& in)
           state = state_fsize0;
         else if (ch == '=' && token == "MAXBACKUPINDEX")
           state = state_maxbackupindex0;
-        else if (ch == '=' && token == "FLUSHDELAY")
-          state = state_flushdelay0;
         else if (ch == '=' && (token == "DISABLE" || token == "DISABLED"))
           state = state_disable;
         else if (ch == '=' && token == "LOGPROCESS")
@@ -792,8 +675,6 @@ void log_init_cxxtools(std::istream& in)
           state = state_fsize0;
         else if (ch == '=' && token == "MAXBACKUPINDEX")
           state = state_maxbackupindex0;
-        else if (ch == '=' && token == "FLUSHDELAY")
-          state = state_flushdelay0;
         else if (ch == '=' && (token == "DISABLE" || token == "DISABLED"))
           state = state_disable;
         else if (ch == '=' && token == "LOGPROCESS")
@@ -956,28 +837,6 @@ void log_init_cxxtools(std::istream& in)
         }
         break;
 
-      case state_flushdelay0:
-        if (ch == '\n')
-        {
-          state = state_0;
-          break;
-        }
-        else if (std::isdigit(ch))
-        {
-          flushdelay = ch - '0';
-          state = state_flushdelay;
-        }
-        else if (!std::isspace(ch))
-          state = state_skip;
-        break;
-
-      case state_flushdelay:
-        if (std::isdigit(ch))
-          flushdelay = flushdelay * 10 + ch - '0';
-        else
-          state = (ch == '\n' ? state_0 : state_skip);
-        break;
-
       case state_disable:
         if (ch == '1' || ch == 't' || ch == 'T' || ch == 'y' || ch == 'Y')
         {
@@ -1046,7 +905,6 @@ void log_init_cxxtools(std::istream& in)
   if (logprocess)
     cxxtools::LoggerImpl::runLoggerProcess(logprocessuser, logprocessgroup);
 
-  cxxtools::LoggerImpl::setFlushDelay(flushdelay);
   cxxtools::reinitializeLoggers();
 }
 
